@@ -1,4 +1,4 @@
-module("support", { teardown: moduleTeardown });
+QUnit.module( "support", { teardown: moduleTeardown } );
 
 function getComputedSupport( support ) {
 	var prop,
@@ -17,81 +17,98 @@ function getComputedSupport( support ) {
 
 var computedSupport = getComputedSupport( jQuery.support );
 
-test( "zoom of doom (#13089)", function() {
-	expect( 1 );
+QUnit.test( "zoom of doom (#13089)", function( assert ) {
+	assert.expect( 1 );
 
 	if ( computedSupport.inlineBlockNeedsLayout ) {
 		ok( document.body.style.zoom, "Added a zoom to the body (#11048, #12869)" );
 	} else {
 		ok( !document.body.style.zoom, "No zoom added to the body" );
 	}
-});
+} );
 
 if ( jQuery.css ) {
-	testIframeWithCallback( "body background is not lost if set prior to loading jQuery (#9239)", "support/bodyBackground.html", function( color, support ) {
-		expect( 2 );
-		var okValue = {
-			"#000000": true,
-			"rgb(0, 0, 0)": true
-		};
-		ok( okValue[ color ], "color was not reset (" + color + ")" );
+	testIframeWithCallback(
+		"body background is not lost if set prior to loading jQuery (#9239)",
+		"support/bodyBackground.html",
+		function( color, support, assert ) {
+			assert.expect( 2 );
+			var okValue = {
+				"#000000": true,
+				"rgb(0, 0, 0)": true
+			};
+			assert.ok( okValue[ color ], "color was not reset (" + color + ")" );
 
-		stop();
-		// Run doc ready tests as well
-		jQuery(function() {
-			deepEqual( jQuery.extend( {}, support ), computedSupport, "Same support properties" );
-			start();
-		});
-	});
+			QUnit.stop();
+
+			// Run doc ready tests as well
+			jQuery( function() {
+				assert.deepEqual( jQuery.extend( {}, support ), computedSupport, "Same support properties" );
+				QUnit.start();
+			} );
+		}
+	);
+
+	testIframeWithCallback(
+		"box-sizing does not affect jQuery.support.shrinkWrapBlocks",
+		"support/shrinkWrapBlocks.html",
+		function( shrinkWrapBlocks, assert ) {
+			assert.expect( 1 );
+			assert.strictEqual(
+				shrinkWrapBlocks,
+				computedSupport.shrinkWrapBlocks,
+				"jQuery.support.shrinkWrapBlocks properties are the same"
+			);
+	} );
 }
 
-testIframeWithCallback( "A background on the testElement does not cause IE8 to crash (#9823)", "support/testElementCrash.html", function() {
-	expect( 1 );
-	ok( true, "IE8 does not crash" );
-});
-
-testIframeWithCallback( "box-sizing does not affect jQuery.support.shrinkWrapBlocks", "support/shrinkWrapBlocks.html", function( shrinkWrapBlocks ) {
-	expect( 1 );
-	strictEqual( shrinkWrapBlocks, computedSupport.shrinkWrapBlocks, "jQuery.support.shrinkWrapBlocks properties are the same" );
-});
-
-
-// This test checkes CSP only for browsers with "Content-Security-Policy" header support
-// i.e. no old WebKit or old Firefox
-testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Security/CSP) restrictions",
-	"support/csp.php",
-	function( support ) {
-		expect( 2 );
-		deepEqual( jQuery.extend( {}, support ), computedSupport, "No violations of CSP polices" );
-
-		stop();
-
-		supportjQuery.get( "data/support/csp.log" ).done(function( data ) {
-			equal( data, "", "No log request should be sent" );
-			supportjQuery.get( "data/support/csp-clean.php" ).done( start );
-		});
+testIframeWithCallback(
+	"A background on the testElement does not cause IE8 to crash (#9823)",
+	"support/testElementCrash.html", function( assert ) {
+		assert.expect( 1 );
+		assert.ok( true, "IE8 does not crash" );
 	}
 );
 
-(function() {
-	var expected,
+// This test checks CSP only for browsers with "Content-Security-Policy" header support
+// i.e. no old WebKit or old Firefox
+testIframeWithCallback(
+	"Check CSP (https://developer.mozilla.org/en-US/docs/Security/CSP) restrictions",
+	"support/csp.php",
+	function( support, assert ) {
+		var done = assert.async();
+
+		assert.expect( 2 );
+		assert.deepEqual( jQuery.extend( {}, support ), computedSupport, "No violations of CSP polices" );
+
+		supportjQuery.get( "data/support/csp.log" ).done( function( data ) {
+			assert.equal( data, "", "No log request should be sent" );
+			supportjQuery.get( "data/support/csp-clean.php" ).done( done );
+		} );
+	}
+);
+
+( function() {
+	var expected, version,
 		userAgent = window.navigator.userAgent;
 
-	if ( /chrome/i.test( userAgent ) ) {
+	if ( /edge\//i.test( userAgent ) ) {
+		version = userAgent.match( /edge\/(\d+)/i )[ 1 ];
 		expected = {
 			"ajax": true,
 			"appendChecked": true,
+			"attributes": true,
 			"boxSizing": true,
 			"boxSizingReliable": true,
-			"changeBubbles": true,
+			"change": true,
 			"checkClone": true,
 			"checkOn": true,
-			"clearCloneStyle": true,
+			"clearCloneStyle": version >= 13,
 			"cors": true,
 			"cssFloat": true,
 			"deleteExpando": true,
 			"enctype": true,
-			"focusinBubbles": false,
+			"focusin": false,
 			"getSetAttribute": true,
 			"hrefNormalized": true,
 			"html5Clone": true,
@@ -104,23 +121,26 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": true,
 			"optDisabled": true,
 			"optSelected": true,
-			"ownLast": false,
+			"ownFirst": true,
+			"pixelMarginRight": true,
 			"pixelPosition": true,
 			"radioValue": true,
 			"reliableHiddenOffsets": true,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": true,
 			"shrinkWrapBlocks": false,
 			"style": true,
-			"submitBubbles": true,
+			"submit": true,
 			"tbody": true
 		};
 	} else if ( /opera.*version\/12\.1/i.test( userAgent ) ) {
 		expected = {
 			"ajax": true,
 			"appendChecked": true,
+			"attributes": true,
 			"boxSizing": true,
 			"boxSizingReliable": true,
-			"changeBubbles": true,
+			"change": true,
 			"checkClone": true,
 			"checkOn": true,
 			"clearCloneStyle": true,
@@ -128,7 +148,7 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"cssFloat": true,
 			"deleteExpando": true,
 			"enctype": true,
-			"focusinBubbles": false,
+			"focusin": false,
 			"getSetAttribute": true,
 			"hrefNormalized": true,
 			"html5Clone": true,
@@ -141,23 +161,26 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": true,
 			"optDisabled": true,
 			"optSelected": true,
-			"ownLast": false,
+			"ownFirst": true,
+			"pixelMarginRight": true,
 			"pixelPosition": true,
 			"radioValue": false,
 			"reliableHiddenOffsets": true,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": false,
 			"shrinkWrapBlocks": false,
 			"style": true,
-			"submitBubbles": true,
+			"submit": true,
 			"tbody": true
 		};
-	} else if ( /trident\/7\.0/i.test( userAgent ) ) {
+	} else if ( /(msie 10\.0|trident\/7\.0)/i.test( userAgent ) ) {
 		expected = {
 			"ajax": true,
 			"appendChecked": true,
+			"attributes": true,
 			"boxSizing": true,
 			"boxSizingReliable": false,
-			"changeBubbles": true,
+			"change": true,
 			"checkClone": true,
 			"checkOn": true,
 			"clearCloneStyle": false,
@@ -165,7 +188,7 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"cssFloat": true,
 			"deleteExpando": true,
 			"enctype": true,
-			"focusinBubbles": true,
+			"focusin": true,
 			"getSetAttribute": true,
 			"hrefNormalized": true,
 			"html5Clone": true,
@@ -178,60 +201,26 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": true,
 			"optDisabled": true,
 			"optSelected": false,
-			"ownLast": false,
+			"ownFirst": true,
+			"pixelMarginRight": true,
 			"pixelPosition": true,
 			"radioValue": false,
 			"reliableHiddenOffsets": true,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": true,
 			"shrinkWrapBlocks": false,
 			"style": true,
-			"submitBubbles": true,
-			"tbody": true
-		};
-	} else if ( /msie 10\.0/i.test( userAgent ) ) {
-		expected = {
-			"ajax": true,
-			"appendChecked": true,
-			"boxSizing": true,
-			"boxSizingReliable": false,
-			"changeBubbles": true,
-			"checkClone": true,
-			"checkOn": true,
-			"clearCloneStyle": false,
-			"cors": true,
-			"cssFloat": true,
-			"deleteExpando": true,
-			"enctype": true,
-			"focusinBubbles": true,
-			"getSetAttribute": true,
-			"hrefNormalized": true,
-			"html5Clone": true,
-			"htmlSerialize": true,
-			"inlineBlockNeedsLayout": false,
-			"input": true,
-			"leadingWhitespace": true,
-			"noCloneChecked": false,
-			"noCloneEvent": true,
-			"opacity": true,
-			"optDisabled": true,
-			"optSelected": false,
-			"ownLast": false,
-			"pixelPosition": true,
-			"radioValue": false,
-			"reliableHiddenOffsets": true,
-			"reliableMarginRight": true,
-			"shrinkWrapBlocks": false,
-			"style": true,
-			"submitBubbles": true,
+			"submit": true,
 			"tbody": true
 		};
 	} else if ( /msie 9\.0/i.test( userAgent ) ) {
 		expected = {
 			"ajax": true,
 			"appendChecked": true,
+			"attributes": true,
 			"boxSizing": true,
 			"boxSizingReliable": false,
-			"changeBubbles": true,
+			"change": true,
 			"checkClone": true,
 			"checkOn": true,
 			"clearCloneStyle": false,
@@ -239,7 +228,7 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"cssFloat": true,
 			"deleteExpando": true,
 			"enctype": true,
-			"focusinBubbles": true,
+			"focusin": true,
 			"getSetAttribute": true,
 			"hrefNormalized": true,
 			"html5Clone": true,
@@ -252,23 +241,26 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": true,
 			"optDisabled": true,
 			"optSelected": false,
-			"ownLast": false,
+			"ownFirst": true,
+			"pixelMarginRight": true,
 			"pixelPosition": true,
 			"radioValue": false,
 			"reliableHiddenOffsets": true,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": true,
 			"shrinkWrapBlocks": false,
 			"style": true,
-			"submitBubbles": true,
+			"submit": true,
 			"tbody": true
 		};
 	} else if ( /msie 8\.0/i.test( userAgent ) ) {
 		expected = {
 			"ajax": true,
 			"appendChecked": true,
+			"attributes": false,
 			"boxSizing": true,
 			"boxSizingReliable": false,
-			"changeBubbles": false,
+			"change": false,
 			"checkClone": true,
 			"checkOn": true,
 			"clearCloneStyle": true,
@@ -276,7 +268,7 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"cssFloat": false,
 			"deleteExpando": false,
 			"enctype": true,
-			"focusinBubbles": true,
+			"focusin": true,
 			"getSetAttribute": true,
 			"hrefNormalized": true,
 			"html5Clone": false,
@@ -289,31 +281,34 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": false,
 			"optDisabled": true,
 			"optSelected": false,
-			"ownLast": true,
+			"ownFirst": false,
+			"pixelMarginRight": true,
 			"pixelPosition": false,
 			"radioValue": false,
 			"reliableHiddenOffsets": false,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": false,
 			"shrinkWrapBlocks": false,
 			"style": false,
-			"submitBubbles": false,
+			"submit": false,
 			"tbody": true
 		};
 	} else if ( /msie 7\.0/i.test( userAgent ) ) {
 		expected = {
 			"ajax": true,
 			"appendChecked": false,
+			"attributes": false,
 			"boxSizing": false,
 			"boxSizingReliable": false,
-			"changeBubbles": false,
-			"checkClone": true,
+			"change": false,
+			"checkClone": false,
 			"checkOn": true,
 			"clearCloneStyle": true,
 			"cors": false,
 			"cssFloat": false,
 			"deleteExpando": false,
 			"enctype": true,
-			"focusinBubbles": true,
+			"focusin": true,
 			"getSetAttribute": false,
 			"hrefNormalized": false,
 			"html5Clone": false,
@@ -326,31 +321,34 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": false,
 			"optDisabled": true,
 			"optSelected": false,
-			"ownLast": true,
+			"ownFirst": false,
+			"pixelMarginRight": true,
 			"pixelPosition": false,
 			"radioValue": false,
 			"reliableHiddenOffsets": false,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": false,
 			"shrinkWrapBlocks": false,
 			"style": false,
-			"submitBubbles": false,
+			"submit": false,
 			"tbody": false
 		};
 	} else if ( /msie 6\.0/i.test( userAgent ) ) {
 		expected = {
 			"ajax": true,
 			"appendChecked": false,
+			"attributes": false,
 			"boxSizing": false,
 			"boxSizingReliable": false,
-			"changeBubbles": false,
-			"checkClone": true,
+			"change": false,
+			"checkClone": false,
 			"checkOn": true,
 			"clearCloneStyle": true,
 			"cors": false,
 			"cssFloat": false,
 			"deleteExpando": false,
 			"enctype": true,
-			"focusinBubbles": true,
+			"focusin": true,
 			"getSetAttribute": false,
 			"hrefNormalized": false,
 			"html5Clone": false,
@@ -363,23 +361,29 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": false,
 			"optDisabled": true,
 			"optSelected": false,
-			"ownLast": true,
+			"ownFirst": false,
+			"pixelMarginRight": true,
 			"pixelPosition": false,
 			"radioValue": false,
 			"reliableHiddenOffsets": false,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": false,
 			"shrinkWrapBlocks": true,
 			"style": false,
-			"submitBubbles": false,
+			"submit": false,
 			"tbody": false
 		};
-	} else if ( /7\.0(\.\d+|) safari/i.test( userAgent ) ) {
+	} else if ( /chrome/i.test( userAgent ) ) {
+
+		// Catches Chrome on Android as well (i.e. the default
+		// Android browser on Android >= 4.4).
 		expected = {
 			"ajax": true,
 			"appendChecked": true,
+			"attributes": true,
 			"boxSizing": true,
 			"boxSizingReliable": true,
-			"changeBubbles": true,
+			"change": true,
 			"checkClone": true,
 			"checkOn": true,
 			"clearCloneStyle": true,
@@ -387,7 +391,7 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"cssFloat": true,
 			"deleteExpando": true,
 			"enctype": true,
-			"focusinBubbles": false,
+			"focusin": false,
 			"getSetAttribute": true,
 			"hrefNormalized": true,
 			"html5Clone": true,
@@ -400,23 +404,26 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": true,
 			"optDisabled": true,
 			"optSelected": true,
-			"ownLast": false,
-			"pixelPosition": false,
+			"ownFirst": true,
+			"pixelMarginRight": true,
+			"pixelPosition": true,
 			"radioValue": true,
 			"reliableHiddenOffsets": true,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": true,
 			"shrinkWrapBlocks": false,
 			"style": true,
-			"submitBubbles": true,
+			"submit": true,
 			"tbody": true
 		};
-	} else if ( /6\.0(\.\d+|) safari/i.test( userAgent ) ) {
+	} else if ( /9\.0(\.\d+|) safari/i.test( userAgent ) ) {
 		expected = {
 			"ajax": true,
 			"appendChecked": true,
+			"attributes": true,
 			"boxSizing": true,
 			"boxSizingReliable": true,
-			"changeBubbles": true,
+			"change": true,
 			"checkClone": true,
 			"checkOn": true,
 			"clearCloneStyle": true,
@@ -424,7 +431,7 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"cssFloat": true,
 			"deleteExpando": true,
 			"enctype": true,
-			"focusinBubbles": false,
+			"focusin": false,
 			"getSetAttribute": true,
 			"hrefNormalized": true,
 			"html5Clone": true,
@@ -437,23 +444,66 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": true,
 			"optDisabled": true,
 			"optSelected": true,
-			"ownLast": false,
+			"ownFirst": true,
+			"pixelMarginRight": true,
 			"pixelPosition": false,
 			"radioValue": true,
 			"reliableHiddenOffsets": true,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": true,
 			"shrinkWrapBlocks": false,
 			"style": true,
-			"submitBubbles": true,
+			"submit": true,
 			"tbody": true
 		};
-	} else if ( /5\.1(\.\d+|) safari/i.test( userAgent ) ) {
+	} else if ( /8\.0(\.\d+|) safari/i.test( userAgent ) ) {
 		expected = {
 			"ajax": true,
 			"appendChecked": true,
+			"attributes": true,
 			"boxSizing": true,
 			"boxSizingReliable": true,
-			"changeBubbles": true,
+			"change": true,
+			"checkClone": true,
+			"checkOn": true,
+			"clearCloneStyle": true,
+			"cors": true,
+			"cssFloat": true,
+			"deleteExpando": true,
+			"enctype": true,
+			"focusin": false,
+			"getSetAttribute": true,
+			"hrefNormalized": true,
+			"html5Clone": true,
+			"htmlSerialize": true,
+			"inlineBlockNeedsLayout": false,
+			"input": true,
+			"leadingWhitespace": true,
+			"noCloneChecked": true,
+			"noCloneEvent": true,
+			"opacity": true,
+			"optDisabled": true,
+			"optSelected": true,
+			"ownFirst": true,
+			"pixelMarginRight": true,
+			"pixelPosition": false,
+			"radioValue": true,
+			"reliableHiddenOffsets": true,
+			"reliableMarginRight": true,
+			"reliableMarginLeft": true,
+			"shrinkWrapBlocks": false,
+			"style": true,
+			"submit": true,
+			"tbody": true
+		};
+	} else if ( /5\.[01](\.\d+|) safari/i.test( userAgent ) ) {
+		expected = {
+			"ajax": true,
+			"appendChecked": true,
+			"attributes": true,
+			"boxSizing": true,
+			"boxSizingReliable": true,
+			"change": true,
 			"checkClone": false,
 			"checkOn": false,
 			"clearCloneStyle": true,
@@ -461,7 +511,7 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"cssFloat": true,
 			"deleteExpando": true,
 			"enctype": true,
-			"focusinBubbles": false,
+			"focusin": false,
 			"getSetAttribute": true,
 			"hrefNormalized": true,
 			"html5Clone": true,
@@ -474,23 +524,66 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": true,
 			"optDisabled": true,
 			"optSelected": true,
-			"ownLast": false,
+			"ownFirst": true,
+			"pixelMarginRight": false,
 			"pixelPosition": false,
 			"radioValue": true,
 			"reliableHiddenOffsets": true,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": false,
 			"shrinkWrapBlocks": false,
 			"style": true,
-			"submitBubbles": true,
+			"submit": true,
+			"tbody": true
+		};
+	} else if ( /6\.0(\.\d+|) safari/i.test( userAgent ) ) {
+		expected = {
+			"ajax": true,
+			"appendChecked": true,
+			"attributes": true,
+			"boxSizing": true,
+			"boxSizingReliable": true,
+			"change": true,
+			"checkClone": true,
+			"checkOn": true,
+			"clearCloneStyle": true,
+			"cors": true,
+			"cssFloat": true,
+			"deleteExpando": true,
+			"enctype": true,
+			"focusin": false,
+			"getSetAttribute": true,
+			"hrefNormalized": true,
+			"html5Clone": true,
+			"htmlSerialize": true,
+			"inlineBlockNeedsLayout": false,
+			"input": true,
+			"leadingWhitespace": true,
+			"noCloneChecked": true,
+			"noCloneEvent": true,
+			"opacity": true,
+			"optDisabled": true,
+			"optSelected": true,
+			"ownFirst": true,
+			"pixelMarginRight": true,
+			"pixelPosition": false,
+			"radioValue": true,
+			"reliableHiddenOffsets": true,
+			"reliableMarginRight": true,
+			"reliableMarginLeft": true,
+			"shrinkWrapBlocks": false,
+			"style": true,
+			"submit": true,
 			"tbody": true
 		};
 	} else if ( /firefox/i.test( userAgent ) ) {
 		expected = {
 			"ajax": true,
 			"appendChecked": true,
+			"attributes": true,
 			"boxSizing": true,
 			"boxSizingReliable": true,
-			"changeBubbles": true,
+			"change": true,
 			"checkClone": true,
 			"checkOn": true,
 			"clearCloneStyle": true,
@@ -498,7 +591,7 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"cssFloat": true,
 			"deleteExpando": true,
 			"enctype": true,
-			"focusinBubbles": false,
+			"focusin": false,
 			"getSetAttribute": true,
 			"hrefNormalized": true,
 			"html5Clone": true,
@@ -511,23 +604,26 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": true,
 			"optDisabled": true,
 			"optSelected": true,
-			"ownLast": false,
+			"ownFirst": true,
+			"pixelMarginRight": true,
 			"pixelPosition": true,
 			"radioValue": true,
 			"reliableHiddenOffsets": true,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": false,
 			"shrinkWrapBlocks": false,
 			"style": true,
-			"submitBubbles": true,
+			"submit": true,
 			"tbody": true
 		};
-	} else if ( /iphone os (?:6|7)_/i.test( userAgent ) ) {
+	} else if ( /iphone os 9_/i.test( userAgent ) ) {
 		expected = {
 			"ajax": true,
 			"appendChecked": true,
+			"attributes": true,
 			"boxSizing": true,
 			"boxSizingReliable": true,
-			"changeBubbles": true,
+			"change": true,
 			"checkClone": true,
 			"checkOn": true,
 			"clearCloneStyle": true,
@@ -535,7 +631,7 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"cssFloat": true,
 			"deleteExpando": true,
 			"enctype": true,
-			"focusinBubbles": false,
+			"focusin": false,
 			"getSetAttribute": true,
 			"hrefNormalized": true,
 			"html5Clone": true,
@@ -548,23 +644,186 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": true,
 			"optDisabled": true,
 			"optSelected": true,
-			"ownLast": false,
+			"ownFirst": true,
+			"pixelMarginRight": true,
 			"pixelPosition": false,
 			"radioValue": true,
 			"reliableHiddenOffsets": true,
 			"reliableMarginRight": true,
+			"reliableMarginLeft": true,
 			"shrinkWrapBlocks": false,
 			"style": true,
-			"submitBubbles": true,
+			"submit": true,
+			"tbody": true
+		};
+	} else if ( /iphone os 8_/i.test( userAgent ) ) {
+		expected = {
+			"ajax": true,
+			"appendChecked": true,
+			"attributes": true,
+			"boxSizing": true,
+			"boxSizingReliable": true,
+			"change": true,
+			"checkClone": true,
+			"checkOn": true,
+			"clearCloneStyle": true,
+			"cors": true,
+			"cssFloat": true,
+			"deleteExpando": true,
+			"enctype": true,
+			"focusin": false,
+			"getSetAttribute": true,
+			"hrefNormalized": true,
+			"html5Clone": true,
+			"htmlSerialize": true,
+			"inlineBlockNeedsLayout": false,
+			"input": true,
+			"leadingWhitespace": true,
+			"noCloneChecked": true,
+			"noCloneEvent": true,
+			"opacity": true,
+			"optDisabled": true,
+			"optSelected": true,
+			"ownFirst": true,
+			"pixelMarginRight": true,
+			"pixelPosition": false,
+			"radioValue": true,
+			"reliableHiddenOffsets": true,
+			"reliableMarginRight": true,
+			"reliableMarginLeft": true,
+			"shrinkWrapBlocks": false,
+			"style": true,
+			"submit": true,
+			"tbody": true
+		};
+	} else if ( /iphone os 7_/i.test( userAgent ) ) {
+		expected = {
+			"ajax": true,
+			"appendChecked": true,
+			"attributes": true,
+			"boxSizing": true,
+			"boxSizingReliable": true,
+			"change": true,
+			"checkClone": true,
+			"checkOn": true,
+			"clearCloneStyle": true,
+			"cors": true,
+			"cssFloat": true,
+			"deleteExpando": true,
+			"enctype": true,
+			"focusin": false,
+			"getSetAttribute": true,
+			"hrefNormalized": true,
+			"html5Clone": true,
+			"htmlSerialize": true,
+			"inlineBlockNeedsLayout": false,
+			"input": true,
+			"leadingWhitespace": true,
+			"noCloneChecked": true,
+			"noCloneEvent": true,
+			"opacity": true,
+			"optDisabled": true,
+			"optSelected": true,
+			"ownFirst": true,
+			"pixelMarginRight": true,
+			"pixelPosition": false,
+			"radioValue": true,
+			"reliableHiddenOffsets": true,
+			"reliableMarginRight": true,
+			"reliableMarginLeft": true,
+			"shrinkWrapBlocks": false,
+			"style": true,
+			"submit": true,
+			"tbody": true
+		};
+	} else if ( /iphone os 6_/i.test( userAgent ) ) {
+		expected = {
+			"ajax": true,
+			"appendChecked": true,
+			"attributes": true,
+			"boxSizing": true,
+			"boxSizingReliable": true,
+			"change": true,
+			"checkClone": true,
+			"checkOn": true,
+			"clearCloneStyle": true,
+			"cors": true,
+			"cssFloat": true,
+			"deleteExpando": true,
+			"enctype": true,
+			"focusin": false,
+			"getSetAttribute": true,
+			"hrefNormalized": true,
+			"html5Clone": true,
+			"htmlSerialize": true,
+			"inlineBlockNeedsLayout": false,
+			"input": true,
+			"leadingWhitespace": true,
+			"noCloneChecked": true,
+			"noCloneEvent": true,
+			"opacity": true,
+			"optDisabled": true,
+			"optSelected": true,
+			"ownFirst": true,
+			"pixelMarginRight": true,
+			"pixelPosition": false,
+			"radioValue": true,
+			"reliableHiddenOffsets": true,
+			"reliableMarginRight": true,
+			"reliableMarginLeft": true,
+			"shrinkWrapBlocks": false,
+			"style": true,
+			"submit": true,
+			"tbody": true
+		};
+	} else if ( /android 4\.[0-3]/i.test( userAgent ) ) {
+		expected = {
+			"ajax": true,
+			"appendChecked": true,
+			"attributes": true,
+			"boxSizing": true,
+			"boxSizingReliable": true,
+			"change": true,
+			"checkClone": false,
+			"checkOn": false,
+			"clearCloneStyle": true,
+			"cors": true,
+			"cssFloat": true,
+			"deleteExpando": true,
+			"enctype": true,
+			"focusin": false,
+			"getSetAttribute": true,
+			"hrefNormalized": true,
+			"html5Clone": true,
+			"htmlSerialize": true,
+			"inlineBlockNeedsLayout": false,
+			"input": true,
+			"leadingWhitespace": true,
+			"noCloneChecked": true,
+			"noCloneEvent": true,
+			"opacity": true,
+			"optDisabled": true,
+			"optSelected": true,
+			"ownFirst": true,
+			"pixelMarginRight": false,
+			"pixelPosition": false,
+			"radioValue": true,
+			"reliableHiddenOffsets": true,
+			"reliableMarginRight": true,
+			"reliableMarginLeft": false,
+			"shrinkWrapBlocks": false,
+			"style": true,
+			"submit": true,
 			"tbody": true
 		};
 	} else if ( /android 2\.3/i.test( userAgent ) ) {
 		expected = {
 			"ajax": true,
 			"appendChecked": true,
+			"attributes": true,
 			"boxSizing": true,
 			"boxSizingReliable": true,
-			"changeBubbles": true,
+			"change": true,
 			"checkClone": true,
 			"checkOn": false,
 			"clearCloneStyle": false,
@@ -572,7 +831,7 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"cssFloat": true,
 			"deleteExpando": true,
 			"enctype": true,
-			"focusinBubbles": false,
+			"focusin": false,
 			"getSetAttribute": true,
 			"hrefNormalized": true,
 			"html5Clone": true,
@@ -585,76 +844,44 @@ testIframeWithCallback( "Check CSP (https://developer.mozilla.org/en-US/docs/Sec
 			"opacity": true,
 			"optDisabled": false,
 			"optSelected": true,
-			"ownLast": false,
+			"ownFirst": true,
+			"pixelMarginRight": true,
 			"pixelPosition": false,
 			"radioValue": true,
 			"reliableHiddenOffsets": true,
 			"reliableMarginRight": false,
+			"reliableMarginLeft": true,
 			"shrinkWrapBlocks": false,
 			"style": true,
-			"submitBubbles": true,
-			"tbody": true
-		};
-	} else if ( /android 4\.[0-3]/i.test( userAgent ) ) {
-		expected = {
-			"ajax": true,
-			"appendChecked": true,
-			"boxSizing": true,
-			"boxSizingReliable": true,
-			"changeBubbles": true,
-			"checkClone": false,
-			"checkOn": false,
-			"clearCloneStyle": true,
-			"cors": true,
-			"cssFloat": true,
-			"deleteExpando": true,
-			"enctype": true,
-			"focusinBubbles": false,
-			"getSetAttribute": true,
-			"hrefNormalized": true,
-			"html5Clone": true,
-			"htmlSerialize": true,
-			"inlineBlockNeedsLayout": false,
-			"input": true,
-			"leadingWhitespace": true,
-			"noCloneChecked": true,
-			"noCloneEvent": true,
-			"opacity": true,
-			"optDisabled": true,
-			"optSelected": true,
-			"ownLast": false,
-			"pixelPosition": false,
-			"radioValue": true,
-			"reliableHiddenOffsets": true,
-			"reliableMarginRight": true,
-			"shrinkWrapBlocks": false,
-			"style": true,
-			"submitBubbles": true,
+			"submit": true,
 			"tbody": true
 		};
 	}
 
-	if ( expected ) {
-		test( "Verify that the support tests resolve as expected per browser", function() {
-			var i, prop,
-				j = 0;
+	QUnit.test( "Verify that support tests resolve as expected per browser", function( assert ) {
+		if ( !expected ) {
+			assert.expect( 1 );
+			assert.ok( false, "Known client: " + userAgent );
+		}
 
-			for ( prop in computedSupport ) {
-				j++;
+		var i, prop,
+			j = 0;
+
+		for ( prop in computedSupport ) {
+			j++;
+		}
+
+		assert.expect( j );
+
+		for ( i in expected ) {
+			if ( jQuery.ajax || i !== "ajax" && i !== "cors" ) {
+				assert.equal( computedSupport[ i ], expected[ i ],
+					"jQuery.support['" + i + "']: " + computedSupport[ i ] +
+						", expected['" + i + "']: " + expected[ i ] );
+			} else {
+				assert.ok( true, "no ajax; skipping jQuery.support['" + i + "']" );
 			}
+		}
+	} );
 
-			expect( j );
-
-			for ( i in expected ) {
-				if ( jQuery.ajax || i !== "ajax" && i !== "cors" ) {
-					equal( computedSupport[i], expected[i],
-						"jQuery.support['" + i + "']: " + computedSupport[i] +
-							", expected['" + i + "']: " + expected[i]);
-				} else {
-					ok( true, "no ajax; skipping jQuery.support['" + i + "']" );
-				}
-			}
-		});
-	}
-
-})();
+} )();
